@@ -1,12 +1,37 @@
 ''' Read config file to provide GHConf object
 '''
+import socket
 import json
 
 class GHConf():
     CONF_FILE = "/home/gh/.gh/gh_conf.json"
 
-    def __init__(self):
-        self.json = self._get_conf()
+    def __init__(self, gh_name:str=None, json:str=None):
+        if gh_name:
+            self.gh_name = gh_name
+        else:
+            hostname = socket.gethostname()
+            if "Greenhouse" in hostname:
+                self.gh_name = hostname 
+            else:
+                self.gh_name = "GreenHouseTestingFFFF"
+
+        if json:
+            self.json = json
+        else:
+            self.json = self._get_conf()
+
+    @property
+    def name(self) -> str:
+        return self.gh_name
+
+    @property
+    def group(self) -> str:
+        return self.gh_name[-4:-2]
+
+    @property
+    def number(self) -> str:
+        return self.gh_name[-2:]
 
     @property
     def version(self) -> str:
