@@ -1,3 +1,5 @@
+import pigpio
+
 class GHLamps(object):
     """A container class to access the IoT Greenhouse lamps.
     """
@@ -35,7 +37,7 @@ class GHLamp(object):
         """
         self._pi = pi
         self._gpio = gpio
-        self._pi.set_mode(self._gpio, self._pi.OUTPUT) 
+        self._pi.set_mode(self._gpio, pigpio.OUTPUT) 
         self._pi.write(self._gpio, self.LAMP_OFF)
 
     def on(self):
@@ -97,11 +99,12 @@ class GHLampDual(object):
         :param gpio2: GPIO port 2 for Dual LED. 
         :returns: GHLampDual object
         """
+        self.pigpio = pigpio
         self._pi = pi
         self._shared_gpio1 = shared_gpio1
         self._gpio2 = gpio2
-        self._pi.set_mode(self._shared_gpio1, self._pi.OUTPUT)   
-        self._pi.set_mode(self._gpio2, self._pi.INPUT) 
+        self._pi.set_mode(self._shared_gpio1, self.pigpio.OUTPUT)   
+        self._pi.set_mode(self._gpio2, pigpio.INPUT) 
         self._pi.write(self._shared_gpio1, True)
         
         self._state = self.LAMP_OFF
@@ -109,7 +112,7 @@ class GHLampDual(object):
     def on_green(self):
         """Activates dual lamp as green.
         """
-        self._pi.set_mode(self._gpio2, self._pi.OUTPUT)
+        self._pi.set_mode(self._gpio2, self.pigpio.OUTPUT)
         self._pi.write(self._shared_gpio1, False)
         self._pi.write(self._gpio2, True)
         self._state = self.LAMP_ON_GREEN
@@ -117,7 +120,7 @@ class GHLampDual(object):
     def on_yellow(self):
         """Activates dual lamp as yellow.
         """
-        self._pi.set_mode(self._gpio2, self._pi.OUTPUT)
+        self._pi.set_mode(self._gpio2, self.pigpio.OUTPUT)
         self._pi.write(self._shared_gpio1, True)
         self._pi.write(self._gpio2, False)
         self._state = self.LAMP_ON_YELLOW
@@ -125,7 +128,7 @@ class GHLampDual(object):
     def off(self):
         """Deactivates dual lamp.
         """
-        self._pi.set_mode(self._gpio2, self._pi.INPUT)
+        self._pi.set_mode(self._gpio2, self.pigpio.INPUT)
         self._state = self.LAMP_OFF
 
     def get_state(self):
