@@ -1,3 +1,5 @@
+import pigpio
+
 class GHServo(object):
     """A class to access the IoT Greenhouse servo.
     """    
@@ -5,15 +7,8 @@ class GHServo(object):
     PERIOD = 1/FREQ
     CCW_PW_LIMIT = 2000
     CW_PW_LIMIT = 500
-
-
-    # _ccw_pulse_width = CCW_PW_LIMIT
-    # _cw_pulse_width = CW_PW_LIMIT
-   
-    # _pulse_width = CCW_PW_LIMIT
     
-    
-    def __init__(self, pi, servo_gpio,  cw_position, ccw_position):
+    def __init__(self, pi, servo_gpio, cw_position, ccw_position):
         """Initializes the IoT Greenhouse servo.
         
         :param pi: reference to pigpio service
@@ -93,26 +88,3 @@ class GHServo(object):
             return "OPEN"
         else:
             return "ACTIVE"
-
-    
-def test_servo():
-    # pi = pigpio.pi()
-    pi = pi()
-    s = GHServo(pi, GHgpio.SERVO_PWM, 1000, 2000)
-    print("move to 0")
-    s.move(0)
-    sleep(3)
-    print("move to +1")
-    s.move(+1)
-    sleep(3)
-    print("move to 0")
-    s.move(0)
-    sleep(3)
-    print("move to +1")
-    s.move(+1)
-    sleep(3)
-
-if __name__ == "__main__":
-    test_servo()
-
-
